diff --git a/doc/pluginsignals.c b/doc/pluginsignals.c
index 0447fb1..1f41012 100644
--- a/doc/pluginsignals.c
+++ b/doc/pluginsignals.c
@@ -140,6 +140,8 @@ signal void (*document_close)(GObject *obj, GeanyDocument *doc, gpointer user_da
  */
 signal void (*project_open)(GObject *obj, GKeyFile *config, gpointer user_data);
 
+signal void (*project_before_save)(GObject *obj, GKeyFile *config, gpointer user_data);
+
 /** Sent when a project is saved(happens when the project is created, the properties
  *  dialog is closed or Geany is exited). This signal is emitted shortly before Geany
  *  will write the contents of the GKeyFile to the disc.
diff --git a/src/geanyobject.c b/src/geanyobject.c
index 23e8af0..bb25ea3 100644
--- a/src/geanyobject.c
+++ b/src/geanyobject.c
@@ -252,6 +252,15 @@ static void create_signals(GObjectClass *g_object_class)
 		g_cclosure_marshal_VOID__POINTER,
 		G_TYPE_NONE, 1,
 		G_TYPE_POINTER);
+	geany_object_signals[GCB_PROJECT_BEFORE_SAVE] = g_signal_new (
+		"project-before-save",
+		G_OBJECT_CLASS_TYPE (g_object_class),
+		G_SIGNAL_RUN_FIRST,
+		G_STRUCT_OFFSET (GeanyObjectClass, project_before_save),
+		NULL, NULL,
+		g_cclosure_marshal_VOID__POINTER,
+		G_TYPE_NONE, 1,
+		G_TYPE_POINTER);
 	geany_object_signals[GCB_PROJECT_SAVE] = g_signal_new (
 		"project-save",
 		G_OBJECT_CLASS_TYPE (g_object_class),
diff --git a/src/geanyobject.h b/src/geanyobject.h
index 3957b55..e7a652d 100644
--- a/src/geanyobject.h
+++ b/src/geanyobject.h
@@ -39,6 +39,7 @@ typedef enum
 	GCB_DOCUMENT_ACTIVATE,
 	GCB_DOCUMENT_CLOSE,
 	GCB_PROJECT_OPEN,
+	GCB_PROJECT_BEFORE_SAVE,
 	GCB_PROJECT_SAVE,
 	GCB_PROJECT_CLOSE,
 	GCB_PROJECT_DIALOG_CREATE,
@@ -88,6 +89,7 @@ struct _GeanyObjectClass
 	void (*document_activate)(GeanyDocument *doc);
 	void (*document_close)(GeanyDocument *doc);
 	void (*project_open)(GKeyFile *keyfile);
+	void (*project_before_save)(GKeyFile *keyfile);
 	void (*project_save)(GKeyFile *keyfile);
 	void (*project_close)(void);
 	void (*project_dialog_create)(GtkWidget *notebook);
diff --git a/src/project.c b/src/project.c
index ca2bc12..d590d18 100644
--- a/src/project.c
+++ b/src/project.c
@@ -1056,6 +1056,8 @@ static gboolean write_config(gboolean emit_signal)
 	g_key_file_set_integer(config, "long line marker", "long_line_behaviour", p->long_line_behaviour);
 	g_key_file_set_integer(config, "long line marker", "long_line_column", p->long_line_column);
 
+	g_signal_emit_by_name(geany_object, "project-before-save", config);
+
 	/* store the session files into the project too */
 	if (project_prefs.project_session)
 		configuration_save_session_files(config);
